

#' RcppDynProg
#' 
#' Rcpp dynamic programming solutions for partitioning and machine learning problems.
#' Includes out of sample fitting applications.  
#' Also supplies additional custom coders for the vtreat package.
#' Please see \url{https://github.com/WinVector/RcppDynProg} for details.
#' 
#' @author John Mount
#' @import Rcpp
#' @importFrom Rcpp evalCpp
#' @useDynLib RcppDynProg
"_PACKAGE" 
